=== modified file 'bzrlib/tests/blackbox/test_mv.py'
--- bzrlib/tests/blackbox/test_mv.py	2006-07-09 20:12:49 +0000
+++ bzrlib/tests/blackbox/test_mv.py	2006-07-11 01:14:17 +0000
@@ -30,10 +30,26 @@
         tree.add(['a', 'c', 'subdir'])
 
         self.run_bzr('mv', 'a', 'b')
+        self.failUnlessExists('b')
+        self.failIfExists('a')
+
         self.run_bzr('mv', 'b', 'subdir')
+        self.failUnlessExists('subdir/b')
+        self.failIfExists('b')
+
         self.run_bzr('mv', 'subdir/b', 'a')
+        self.failUnlessExists('a')
+        self.failIfExists('subdir/b')
+
         self.run_bzr('mv', 'a', 'c', 'subdir')
+        self.failUnlessExists('subdir/a')
+        self.failUnlessExists('subdir/c')
+        self.failIfExists('a')
+        self.failIfExists('c')
+
         self.run_bzr('mv', 'subdir/a', 'subdir/newa')
+        self.failUnlessExists('subdir/newa')
+        self.failIfExists('subdir/a')
 
     def test_mv_unversioned(self):
         self.build_tree(['unversioned.txt'])
@@ -49,15 +65,6 @@
     def test_mv_unqualified(self):
         self.run_bzr_error(['^bzr: ERROR: missing file argument$'], 'mv')
         
-    def test_mv_newly_added(self):
-        tree = self.make_branch_and_tree('.')
-        self.build_tree(['test.txt'])
-        tree.add(['test.txt'])
-
-        self.run_bzr('mv', 'test.txt', 'hello.txt')
-        self.failUnlessExists("hello.txt")
-        self.failIfExists("test.txt")
-
     def test_mv_invalid(self):
         tree = self.make_branch_and_tree('.')
         self.build_tree(['test.txt', 'sub1/'])
@@ -65,27 +72,22 @@
 
         self.run_bzr_error(
             ["^bzr: ERROR: destination u'sub1' is not a versioned directory$"],
-            'rename', 'test.txt', 'sub1')
+            'mv', 'test.txt', 'sub1')
         
         self.run_bzr_error(
             ["^bzr: ERROR: can't determine destination directory id for u'sub1'$"],
-            'rename', 'test.txt', 'sub1/hello.txt')
+            'mv', 'test.txt', 'sub1/hello.txt')
         
-        self.run_bzr_error(
-            ["^bzr: ERROR: destination u'sub1' is not a versioned directory$"],
-            'move', 'test.txt', 'sub1')
-    
     def test_mv_dirs(self):
         tree = self.make_branch_and_tree('.')
         self.build_tree(['hello.txt', 'sub1/'])
         tree.add(['hello.txt', 'sub1'])
 
-        self.run_bzr('rename', 'sub1', 'sub2')
-        self.run_bzr('move', 'hello.txt', 'sub2')
-
-        self.failUnlessExists("sub2")
+        self.run_bzr('mv', 'sub1', 'sub2')
+        self.failUnlessExists('sub2')
+        self.failIfExists('sub1')
+        self.run_bzr('mv', 'hello.txt', 'sub2')
         self.failUnlessExists("sub2/hello.txt")
-        self.failIfExists("sub1")
         self.failIfExists("hello.txt")
 
         tree.read_working_inventory()
@@ -93,26 +95,36 @@
 
         self.build_tree(['sub1/'])
         tree.add(['sub1'])
-        self.run_bzr('move', 'sub2/hello.txt', 'sub1')
+        self.run_bzr('mv', 'sub2/hello.txt', 'sub1')
         self.failIfExists('sub2/hello.txt')
         self.failUnlessExists('sub1/hello.txt')
-        self.run_bzr('move', 'sub2', 'sub1')
+        self.run_bzr('mv', 'sub2', 'sub1')
         self.failIfExists('sub2')
         self.failUnlessExists('sub1/sub2')
 
-    def test_mv_relative(self): 
+    def test_mv_relative(self):
         self.build_tree(['sub1/', 'sub1/sub2/', 'sub1/hello.txt'])
         tree = self.make_branch_and_tree('.')
         tree.add(['sub1', 'sub1/sub2', 'sub1/hello.txt'])
         tree.commit('initial tree')
 
         os.chdir('sub1/sub2')
-        self.run_bzr('move', '../hello.txt', '.')
+        self.run_bzr('mv', '../hello.txt', '.')
         self.failUnlessExists('./hello.txt')
         tree.read_working_inventory()
         tree.commit('move to parent directory')
 
         os.chdir('..')
 
-        self.run_bzr('move', 'sub2/hello.txt', '.')
+        self.run_bzr('mv', 'sub2/hello.txt', '.')
         self.failUnlessExists('hello.txt')
+
+    def test_mv_smoke_aliases(self):
+        # just test that aliases for mv exist, if their behaviour is changed in
+        # the future, then extend the tests.
+        self.build_tree(['a'])
+        tree = self.make_branch_and_tree('.')
+        tree.add(['a'])
+
+        self.run_bzr('move', 'a', 'b')
+        self.run_bzr('rename', 'b', 'a')

